#!/bin/bash

#    Automates the packaging process of the software "xorg-utils" for
#    use with Zenwalk Linux.
#    
#    Copyright (C) 2008 Michael Verret
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

#    xorg-utils Home Page: xorg-utils
#    xorg-utils Sources: http://xorg.freedesktop.org/releases/individual/util/
#    xorg-utils Dependencies: "gcc,perl"


#------------------( Unique Package Variables )


SOFTNAME='xorg-utils'
SOFTVERSION='7.4'
BUILDVERSION='62.2'
SOURCEVERSION="${SOFTVERSION}"
BUILDARCH='i686'
BUILDCPU='i686'
DOCS="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"

SOURCES=" \
gccmakedep-1.0.2.tar.bz2 \
imake-1.0.2.tar.bz2 \
lndir-1.0.1.tar.bz2 \
makedepend-1.0.1.20090219git.tar.bz2 \
util-macros-1.2.1.tar.bz2 \
xorg-cf-files-1.0.2.tar.bz2"

SCRIPTS=" \
doinst.sh.gz"


#------------------( Make Sure That We Have Everything )


for file in ${SOURCES} ; do
  echo -n "$file :"
  if [ -e $file ]; then
    echo " OK"
  else
    echo " MISSING !"
    exit 1
  fi
done


#------------------( Standard Variables & Routines )


BUILDIR=$(pwd)
cd ${BUILDIR}
PACKAGE="${SOFTNAME}-${SOFTVERSION}-${BUILDARCH}-${BUILDVERSION}"
INSTALLDIR="${BUILDIR}/${PACKAGE}"

rm -rf {${INSTALLDIR}*,${PACKAGE}*.md5} 1>/dev/null 2>&1


#------------------( Build & Install The Software )


cd ${BUILDIR}
for file in ${SOURCES} ; do
  if [ "$(echo $file | grep ".tar.bz2" )" ]; then
      SOURCEDIR="$(basename $file .tar.bz2)"
      rm -rf ${SOURCEDIR}
      mkdir -p ${INSTALLDIR}/usr/doc/${SOURCEDIR}
      tar jxvf $file
  elif [ "$(echo $file | grep ".tar.gz" )" ]; then
      SOURCEDIR="$(basename $file .tar.gz)"
      rm -rf ${SOURCEDIR}
      mkdir -p ${INSTALLDIR}/usr/doc/${SOURCEDIR}
      tar zxvf $file
  fi
  (
    cd ${SOURCEDIR}
      chown -R root:root .
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;

	./configure \
	CFLAGS="-O2 -march=${BUILDARCH} -pipe" \
	CXXFLAGS="${CFLAGS}" \
	  --prefix=/usr \
	  --sysconfdir=/etc \
	  --localstatedir=/var \
	  --infodir=/usr/info \
	  --mandir=/usr/man \
	  --disable-static
    
	make -j1 || exit 1
	make install DESTDIR=${INSTALLDIR}

	cp ${DOCS} ${INSTALLDIR}/usr/doc/${SOURCEDIR}  1>/dev/null 2>&1
        rm -rf ${BUILDIR}/${SOURCEDIR}
    (
      cd ${INSTALLDIR}/usr/doc/${SOURCEDIR}
      find . -name "*" -size 0c -exec rm {} \;
    )
  )
done


#------------------( Add Slack-desc )


mkdir -p ${INSTALLDIR}/install
cat <<EOF > ${PACKAGE}/install/slack-desc 
          |-----handy-ruler------------------------------------------------------|
xorg-utils: xorg-utils (Collection of utilities for the X server)
xorg-utils:
xorg-utils: This package contains numerous useful utilities
xorg-utils: for the X server. Such utilities include gccmakedep
xorg-utils: and Imake which are required to build some types
xorg-utils: of X related software.
xorg-utils:
xorg-utils: 
xorg-utils: 
xorg-utils:
xorg-utils:
EOF


#------------------( Strip Binaries )


( cd ${INSTALLDIR}
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


#------------------( Add doinst.sh )


zcat ${BUILDIR}/doinst.sh.gz > ${PACKAGE}/install/doinst.sh


#------------------( Add Buildscript & doinst.sh )


mkdir -p ${INSTALLDIR}/usr/src/${SOFTNAME}-${SOFTVERSION}

cp ${BUILDIR}/build-${SOFTNAME}.sh ${SCRIPTS} \
	${INSTALLDIR}/usr/src/${SOFTNAME}-${SOFTVERSION}/


#------------------( Remove the empty host.def: )


rm -f ${INSTALLDIR}/usr/lib/X11/config/host.def


#------------------( Track Package Dependencies )


cd ${INSTALLDIR}
requiredbuilder -z ${INSTALLDIR} >> ${BUILDIR}/${PACKAGE}.dep


#------------------( Compress The Man Pages )


gzip -9 ${INSTALLDIR}/usr/man/*/* 1>/dev/null 2>&1


#------------------( Compress The Package )


cd ${INSTALLDIR}
makepkg -l y -c n ${BUILDIR}/${PACKAGE}.tgz


#------------------( Calculate The MD5 Sum )

cd ${BUILDIR}
md5sum ${PACKAGE}.tgz > ${PACKAGE}.md5
rm -rf ${PACKAGE}
